#!/usr/bin/env python
# -*- coding: utf-8 -*-

from app import create_app
from app.libs.error import APIException
from werkzeug.exceptions import HTTPException
from app.libs.error_code import ServerError500, MethodException

app = create_app()


@app.errorhandler(Exception)
def framework_error(e):
    print("发生错误啦 => ", e)
    if isinstance(e, APIException):
        return e
    elif isinstance(e, HTTPException):
        if e.code == 405:
            # 请求的URL不允许使用该方法
            return MethodException()
        else:
            code = e.code
            msg = e.description
            error_code = 4999
            return APIException(msg + "HTTP Exception 4999", code, error_code)
    else:
        print(e)
        return ServerError500()


if __name__ == '__main__':
    app.run(host="0.0.0.0", port=10089, debug=True)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

from flask_pymongo import PyMongo
from flask_redis import FlaskRedis


def get_init_log():
    from xtn_tools_pro.utils.log import Log
    logger = Log('{{ project_name }}', './xxx.log', log_level='DEBUG', is_write_to_console=True,
                 is_write_to_file=True,
                 color=True, mode='a', save_time_log_path='./logs')
    return logger


redis_db_01 = FlaskRedis(decode_responses=True, config_prefix="REDIS_01")  # decode_responses=True：连接redis存的数据是字符串格式
redis_db_02 = FlaskRedis(decode_responses=True, config_prefix="REDIS_02")  # decode_responses=True：连接redis存的数据是字符串格式
mongo_db_01 = PyMongo()
logger = get_init_log()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from app.libs.error import APIException


class ServerError500(APIException):
    code = 500
    error_code = 5000
    msg = 'sorry, we made a mistake (*￣︶￣)!'


class Success200(APIException):
    # 成功
    code = 200
    error_code = 2000
    msg = "成功"


class NotFound400(APIException):
    code = 400
    error_code = 4000
    msg = '资源未找到'


class ParameterException(NotFound400):
    msg = '无效的参数'
    error_code = 4001


class MethodException(NotFound400):
    msg = '请求的URL不允许使用该方法'
    error_code = 4002


class TokenException(NotFound400):
    msg = 'token认证不通过'
    error_code = 4003


class Error600(APIException):
    code = 600
    error_code = 6000
    msg = '未知错误'







#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    服务器批量操作
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2025/4/2    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
from fabric import Connection, Config
from xtn_tools_pro.utils.log import Log


class ShellPro:
    def __init__(self, server_info_list):
        self.server_info_list = server_info_list
        self.__logger = Log('shell', './xxx.log', log_level='DEBUG', is_write_to_console=True,
                            is_write_to_file=False,
                            color=True, mode='a', save_time_log_path='./logs')

        for _ in range(len(self.server_info_list)):
            ip, pwd, tips = self.server_info_list[_]["ip"], \
                            self.server_info_list[_]["pwd"], \
                            self.server_info_list[_]["tips"]
            self.__logger.info(f"{tips} 正在连接...")
            config = Config(overrides={'sudo': {'password': pwd}})
            conn = Connection(
                host=ip,
                user="root",  # 根据实际情况修改用户名
                connect_kwargs={"password": pwd},
                config=config
            )
            self.server_info_list[_]["conn"] = conn
            self.__logger.info(f"{tips} 连接成功!!!")

    def run_shell(self, conn, cmd, warn=False):
        """
            传入conn和命令执行
        :param conn:
        :param cmd:
        :return:
        """
        conn.run(cmd, warn=warn)

    def update_file(self, local_file, remote_file, mkdir=False):
        """
            覆盖远程文件
        :param local_file: 本地文件
        :param remote_file: 远程文件
        :param mkdir: 是否先在远程创建该路径的文件夹
        :return:
        """
        for server_item in self.server_info_list:
            ip = server_item["ip"]
            tips = server_item["tips"]
            conn = server_item["conn"]
            if mkdir:
                cmd = f"mkdir -p {remote_file}"
                self.run_shell(conn, cmd=cmd, warn=True)
            conn.put(local_file, remote_file)
            self.__logger.info(f"{tips}-{ip} 覆盖远程文件成功!!!")


if __name__ == '__main__':
    server_info_list = [
        {"ip": "xxx.xxx.xx.xxx", "pwd": "123456", "tips": "服务器_01"},
    ]
    sh = ShellPro(server_info_list=server_info_list)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from app.libs.redprint import Redprint
from app.libs.token_auth import user_auth
from app.libs.error_code import Success200
from app.validators.ios import UpdateDataFileValidatorsForm

obj = "demo"
api = Redprint(obj)


@api.route("/pro", methods=["POST"])
@user_auth.login_required
def ai_pro():
    form = UpdateDataFileValidatorsForm().validate_for_api()
    xxxxx = form.xxxxx.data
    return Success200(data=xxxxx)







#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    小象代理专用
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2024/4/27    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
import requests, time, random
from xtn_tools_pro.db.RedisDB import RedisDBPro
from xtn_tools_pro.utils.time_utils import get_time_now_timestamp, get_time_now_day59_timestamp

import warnings
from urllib3.exceptions import InsecureRequestWarning

warnings.filterwarnings("ignore", category=InsecureRequestWarning)


class ProxyPool:
    def __init__(self, ip, port, db=0, user_pass="", redis_proxy_name="XiaoXiangProxy",
                 XiaoXiangProxyAppKey=None, XiaoXiangProxyAppSecret=None, usage_cnt=100, usage_time=100):
        """
            小象代理专用
        :param ip: redis 数据库 ip
        :param port: redis 数据库 端口
        :param db: redis 数据库 db
        :param user_pass: redis 数据库 密码
        :param redis_proxy_name: redis 数据库 用于存储代理的key
        :param XiaoXiangProxyAppKey: 小象代理 应用id appKey
        :param XiaoXiangProxyAppSecret: 小象代理 应用密码 appSecret
        :param usage_cnt: 每个代理最长使用次数 单位秒 维护代理时用
        :param usage_time: 每个代理最长使用时间 单位秒 维护代理时用
        :param is_log: 是否记录日志
        """
        if not XiaoXiangProxyAppSecret or not XiaoXiangProxyAppKey:
            raise Exception("应用密码或应用id 不能为空")

        r = RedisDBPro(ip=ip, port=port, db=db, user_pass=user_pass)
        self.__redis_pool = r
        self.__redisProxyName = redis_proxy_name
        self.__XiaoXiangProxyAPI = "https://api.xiaoxiangdaili.com/ip/get?appKey={appKey}&appSecret={appSecret}&cnt=&wt=json".format(
            appKey=XiaoXiangProxyAppKey, appSecret=XiaoXiangProxyAppSecret)
        self.__XiaoXiangAutoBinding = "https://api.xiaoxiangdaili.com/app/bindIp?appKey={appKey}&appSecret={appSecret}&i=1".format(
            appKey=XiaoXiangProxyAppKey, appSecret=XiaoXiangProxyAppSecret)

        # 获取当天0点时间戳
        self.__now_day59_timestamp = get_time_now_day59_timestamp()
        self.__usage_cnt = usage_cnt
        self.__usage_time = usage_time

        # if is_log:
        #     # 日志
        #     nowDate = str(datetime.datetime.now().strftime('%Y_%m_%d'))
        #     logger.add(loggerPath.format(t=nowDate))

        self.bind_ip()

    def __log(self, text):
        """
            记录日志
        :param text:
        :return:
        """
        print(text)

    def __check_proxy(self):
        """
            维护检查代理，删除无用代理
            删除标准：1.代理使用超过xx次；2.使用时间超过xx秒；3.被爬虫标记使用次数为 999999 会被删除
        :return:
        """
        proxy_val_list = list(self.__redis_pool.get_all_key("{}*".format(self.__redisProxyName)))
        for proxy_val in proxy_val_list:
            # 获取时间
            time_out = proxy_val.split(":")[-1]
            # 获取使用次数
            proxy_val_count = int(self.__redis_pool.get(proxy_val))
            if int(time_out) + self.__usage_time < get_time_now_timestamp(is_time_10=True):
                del_state = self.__redis_pool.delete(proxy_val)
                self.__log(
                    "当前代理状态:{proxy_val},{time_out}_{py_time}当前代理已超过使用时间,删除状态为：{del_state}".
                        format(proxy_val=proxy_val, del_state=del_state,
                               time_out=time_out, py_time=get_time_now_timestamp(is_time_10=True)))
            elif int(proxy_val_count) >= self.__usage_cnt:
                del_state = self.__redis_pool.delete(proxy_val)
                self.__log(
                    "当前代理状态:{proxy_val},{text},删除状态为：{del_state}".format(proxy_val=proxy_val,
                                                                         text="当前代理被爬虫标记为不可用" if proxy_val_count >= 999999 else "当前代理已超过使用时间",
                                                                         del_state=del_state))

    def __get_proxy_length(self):
        """
            获取代理数
        :return:
        """
        proxy_val_list = list(self.__redis_pool.get_all_key("{}*".format(self.__redisProxyName)))
        return len(proxy_val_list)

    def __incr_proxy(self, proxy_val):
        """
            自增代理使用次数
        :param proxy_val: 代理
        :return:
        """
        proxy_val_con = self.__redis_pool.incr(proxy_val)
        return proxy_val_con

    def __get_api_proxy(self):
        """
            通过接口获取小象代理，并存储至数据库
            响应：
                {"code":1010,"success":false,"data":null,"msg":"请求过于频繁"}
                {"code":200,"success":true,"data":[{"ip":"125.123.244.60","port":37635,"realIp":null,"startTime":"2024-04-27 14:09:42","during":2}],"msg":"操作成功"}
        :return:
        """
        while True:
            self.__check_proxy()
            try:
                response = requests.get(url=self.__XiaoXiangProxyAPI, verify=False, timeout=3)
                if response.status_code == 200:
                    if response.json().get("msg") == "请求过于频繁":
                        self.__log("获取小象代理过于频繁，等待2s，{content}".format(content=response.text))
                        time.sleep(2)
                        continue
                    # 获取data
                    proxy_data_list = response.json().get("data", [])
                    if not proxy_data_list:
                        self.__log("获取小象代理失败 data 为空，等待2s，{content}".format(content=response.text))
                        time.sleep(2)
                        continue
                    else:
                        for data in proxy_data_list:
                            ip = "http://{ip}".format(ip=data.get("ip"))
                            port = data.get("port")
                            time_out = get_time_now_timestamp(is_time_10=True)
                            proxy_key = "{redis_proxy_name}:{ip}:{port}:{timeOut}".format(
                                redis_proxy_name=self.__redisProxyName,
                                ip=ip,
                                port=port,
                                timeOut=time_out,
                            )
                            proxy_key_con = self.__incr_proxy(proxy_key)
                            self.__log("获取代理:{proxy_key}，插入数据库状态为{proxy_key_con}".format(proxy_key=proxy_key,
                                                                                         proxy_key_con=proxy_key_con))
                        return True  # 获取成功
                else:
                    self.__log("获取小象代理返回响应码不为200，等待2s，{content}".format(content=response.text))
                    time.sleep(2)
                    continue
            except Exception as e:
                self.__log("获取小象代理报错：{e}".format(e=e))

    def bind_ip(self):
        # 手动绑定终端IP
        response = requests.get(url=self.__XiaoXiangAutoBinding, verify=False, timeout=3)
        self.__log(response.text)

    def run(self):
        while True:
            try:
                self.bind_ip()
                while True:
                    # 检查代理
                    self.__check_proxy()
                    # 获取小象代理
                    self.__get_api_proxy()
                    time.sleep(1)
                    # 判断时间是否超过当前23:59分时间戳
                    # t_a = get_time_now_timestamp(is_time_10=True)
                    # if t_a >= self.__now_day59_timestamp:
                    #     self.__log(
                    #         "时间23:59，结束循环，{t} {a} {a_v} {b} {b_v}".format(t=int(time.time()),
                    #                                                       a=type(t_a),
                    #                                                       a_v=t_a,
                    #                                                       b=type(self.__now_day59_timestamp),
                    #                                                       b_v=self.__now_day59_timestamp)
                    #     )
                    #     break
            except Exception as eee:
                self.__log("程序异常报错:{eee} {b_t} {b_v}".format(eee=eee,
                                                             b_t=type(self.__now_day59_timestamp),
                                                             b_v=self.__now_day59_timestamp))
                self.__check_proxy()
                # self.__del__()

    def get_proxy(self):
        """
            从代理池中获取代理
        :return:
        """
        try:
            while True:
                proxy_val_list = list(self.__redis_pool.get_all_key("{}*".format(self.__redisProxyName)))
                if proxy_val_list:
                    proxy_val = random.choice(proxy_val_list)
                    proxy_v = ":".join(str(proxy_val).split(":")[1:-1])
                    self.__log("获取到的代理为：{proxy_v}".format(proxy_v=proxy_v))
                    return proxy_v
                else:
                    self.__log("暂无代理，等待中")
                    time.sleep(2)
        except Exception as e:
            self.__log("从代理池中获取代理：{e}".format(e=e))

    def set_proxy_error(self, proxy_v):
        """
            爬虫手动传入代理，设置为 999999 不可用
        :param proxyV:
        :return:
        """
        try:
            proxy_val_list = list(self.__redis_pool.get_all_key("{}*".format(self.__redisProxyName)))
            for proxy_val in proxy_val_list:
                if proxy_v in proxy_val:
                    self.__redis_pool.set(proxy_val, "999999")
                    self.__log("设置不可用的代理 {proxy_v} 为 999999".format(proxy_v=proxy_v))
                    return
        except Exception as e:
            self.__log("爬虫手动传入代理：{e}".format(e=e))


if __name__ == '__main__':
    p = ProxyPool(ip="127.0.0.1", port=6379, db=0, user_pass="xtn-kk", XiaoXiangProxyAppKey="1107231349661913088",
                  XiaoXiangProxyAppSecret="8kignGIX")
    # print(p.set_proxy_error("http://49.83.105.188:32300"))
    p.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    程序说明xxxxxxxxxxxxxxxxxxx
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2025/3/13    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
import os
import shutil
import argparse


def replace_placeholders(file_path, project_name):
    """
    替换文件中的占位符 {{ project_name }} 为实际的项目名称
    """
    with open(file_path, 'r', encoding='utf-8') as file:
        content = file.read()

    # 替换占位符
    content = content.replace("{{ project_name }}", project_name)

    with open(file_path, 'w', encoding='utf-8') as file:
        file.write(content)


def create_project(args):
    """
    创建 flask 常用项目结构
    """
    # 获取当前目录
    project_name = args.obj_name
    current_dir = os.getcwd()
    project_dir = os.path.join(current_dir, project_name)

    # 创建项目目录
    os.makedirs(project_dir, exist_ok=True)

    # 复制模板文件到项目目录
    template_dir = os.path.join(os.path.dirname(__file__), 'templates')
    # print("template_dir", template_dir)
    # print("project_dir", project_dir)
    for item in os.listdir(template_dir):
        src = os.path.join(template_dir, item)
        dst = os.path.join(project_dir, item)
        # print("item", item)
        # print("src", src)
        # print("dst", dst)
        # print("==========================")

        if os.path.isdir(src):
            shutil.copytree(src, dst)  # 判断是否为目录,递归地复制整个目录树
        else:
            shutil.copy2(src, dst)

        # 如果是文件，替换占位符
        if os.path.isfile(dst):
            replace_placeholders(dst, project_name)


class CustomArgumentParser(argparse.ArgumentParser):
    def error(self, message):
        # 自定义错误消息
        # self.print_help()
        print("错误：缺少必需的参数！")
        print("请使用以下格式运行：xtn_tools_pro startobj <项目名称>")
        self.exit(2)  # 退出程序，返回状态码 2


def main():
    """
    命令行入口
    """
    parser = CustomArgumentParser(description="创建一个常用的flask项目结构")  # 创建 ArgumentParser 对象
    subparsers = parser.add_subparsers(title="命令", dest="command")

    parser_startobj = subparsers.add_parser('startobj', help="项目名称")  # 添加位置参数
    parser_startobj.add_argument("obj_name", type=str, help="项目的名称")
    parser_startobj.set_defaults(func=create_project)  # 绑定处理函数

    args = parser.parse_args()

    # 如果没有提供子命令，显示帮助信息
    if not hasattr(args, "func"):
        parser.print_help()
        return

    # 调用子命令对应的处理函数
    args.func(args)


if __name__ == "__main__":
    main()
